# pyvespa

[![Documentation Status](https://readthedocs.org/projects/pyvespa/badge/?version=latest)](https://pyvespa.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/vespa-engine/pyvespa.svg?branch=master)](https://travis-ci.org/vespa-engine/pyvespa)

[Vespa](https://vespa.ai/) is the scalable open-sourced serving engine that enable us to store, compute and rank big data at user serving time. `pyvespa` provides a python API to Vespa. It allow us to create, modify, deploy and interact with running Vespa instances. The main goal of the library is to allow for faster prototyping and to facilitate Machine Learning experiments for Vespa applications.

* [pyvespa official documentation](https://pyvespa.readthedocs.io/en/latest/index.html) 
